Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Store ¶
type Store struct {
// contains filtered or unexported fields
}
func (*Store) Get ¶
func (s *Store) Get() interface{}
Get returns the value of the data that's kept in the current state / Store
func (*Store) Subscribe ¶
func (s *Store) Subscribe(callback interface{})
Subscribe will subscribe to updates to the store by providing a callback. Any updates to the store are sent to the callback
func (*Store) Update ¶
func (s *Store) Update(updater interface{})
Update takes a function that is passed the current state. The result of that function is then set as the new state of the store. This will notify listeners of the change
func (*Store) UseAsyncCallbacks ¶
Click to show internal directories.
Click to hide internal directories.